<?php
/**
 * Plugin Name: Wavee Core
 * Plugin URI: https://themeforest.net/user/droitthemes/portfolio
 * Description: This plugin adds the core features to the Wavee WordPress theme. You must have to install this plugin to get all the features included with the theme.
 * Version: 1.3.2
 * Author: DroitThemes
 * Author URI: https://themeforest.net/user/droitthemes/portfolio
 * Text domain: wavee-core
 */

if ( !defined('ABSPATH') )
    die('-1');

if ( !defined( "WAVEE_CORE_FILE" ) ) {
    define( "WAVEE_CORE_FILE", __FILE__ );
}

if ( !defined( "WAVEE_CORE_DIR_PATH" ) ) {
    define ( "WAVEE_CORE_DIR_PATH", plugin_dir_path( WAVEE_CORE_FILE ) );
}


// Make sure the same class is not loaded twice in free/premium versions.
if ( !class_exists( 'Wavee_core' ) ) {
	/**
	 * Main Wavee Core Class
	 *
	 * The main class that initiates and runs the Wavee Core plugin.
	 *
	 * @since 1.7.0
	 */
	final class Wavee_core {
		/**
		 * Wavee Core Version
		 *
		 * Holds the version of the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string The plugin version.
		 */
		const VERSION = '1.0' ;
		/**
		 * Minimum Elementor Version
		 *
		 * Holds the minimum Elementor version required to run the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string Minimum Elementor version required to run the plugin.
		 */
		const MINIMUM_ELEMENTOR_VERSION = '1.7.0';
		/**
		 * Minimum PHP Version
		 *
		 * Holds the minimum PHP version required to run the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string Minimum PHP version required to run the plugin.
		 */
		const  MINIMUM_PHP_VERSION = '5.4' ;
        /**
         * Plugin's directory paths
         * @since 1.0
         */
        const CSS = null;
        const JS = null;
        const IMG = null;
        const VEND = null;

		/**
		 * Instance
		 *
		 * Holds a single instance of the `Wavee_Core` class.
		 *
		 * @since 1.7.0
		 *
		 * @access private
		 * @static
		 *
		 * @var Wavee_Core A single instance of the class.
		 */
		private static  $_instance = null ;
		/**
		 * Instance
		 *
		 * Ensures only one instance of the class is loaded or can be loaded.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 * @static
		 *
		 * @return Wavee_Core An instance of the class.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Clone
		 *
		 * Disable class cloning.
		 *
		 * @since 1.7.0
		 *
		 * @access protected
		 *
		 * @return void
		 */
		public function __clone() {
			// Cloning instances of the class is forbidden
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'wavee-core' ), '1.7.0' );
		}

		/**
		 * Wakeup
		 *
		 * Disable unserializing the class.
		 *
		 * @since 1.7.0
		 *
		 * @access protected
		 *
		 * @return void
		 */
		public function __wakeup() {
			// Unserializing instances of the class is forbidden.
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'wavee-core' ), '1.7.0' );
		}

		/**
		 * Constructor
		 *
		 * Initialize the Wavee Core plugins.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function __construct() {

            // Wavee Core Icons
            add_filter( 'elementor/icons_manager/additional_tabs', [ $this, 'wavee_core_fontawesome_pro']);
            //self :: generate_custom_font_icons();

			$this->core_includes();
			$this->init_hooks();
			do_action( 'wavee_core_loaded' );
		}


        /***
         * Custom Font Icon Integrated Elementor Icon Library
         */
        // Register Icomoon Font Icons
        public function wavee_core_fontawesome_pro( $custom_fonts ){
            $css_data = WAVEE_DIR_VEND . '/font-awesome/css/all.css';
            $json_data = plugins_url( 'assets/fonts/font-awesome-pro.json', __FILE__ );

            $custom_fonts['wavee_core_fontawesome_pro'] = [
                'name'          => 'wavee_core_fontawesome_pro',
                'label'         => esc_html__( 'Wavee FontAwesome Pro Icons', 'wavee-core' ),
                'url'           => $css_data,
                'prefix'        => 'fa-',
                'displayPrefix' => 'fal',
                'labelIcon'     => 'eicon-filter',
                'ver'           => '',
                'fetchJson'     => $json_data,
                'native'        => true,
            ];

            return $custom_fonts;
        }

        public static function generate_custom_font_icons(){
            $css_source = '';
            global $wp_filesystem;
            require_once ( ABSPATH . '/wp-admin/includes/file.php' );
            WP_Filesystem();
            $css_file =  WAVEE_CORE_DIR_PATH . '/assets/fonts/font-awesome/css/all.css';
            if ( $wp_filesystem->exists( $css_file ) ) {
                $css_source = $wp_filesystem->get_contents( $css_file );
            }
            preg_match_all( "/\.(fa-.*?):\w*?\s*?{/", $css_source, $matches, PREG_SET_ORDER, 0 );
            $iconList = [];
            foreach ( $matches as $match ) {
                $icon = str_replace('fa-', '', $match[1]);
                $icons = explode(' ', $icon);
                $iconList[] = current($icons);
            }
            $icons = new \stdClass();
            $icons->icons = $iconList;
            $icon_data = json_encode($icons);
            $file = WAVEE_CORE_DIR_PATH . '/assets/fonts/font-awesome-pro.json';
            global $wp_filesystem;
            require_once ( ABSPATH . '/wp-admin/includes/file.php' );
            WP_Filesystem();
            if ( $wp_filesystem->exists( $file ) ) {
                $content =  $wp_filesystem->put_contents( $file, $icon_data) ;
            }
        }


		/**
		 * Include Files
		 *
		 * Load core files required to run the plugin.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function core_includes() {

            $opt = get_option('wavee_opt');
            $is_service_cpt = isset($opt['is_service_cpt']) ? $opt['is_service_cpt'] : '1';
            $is_portfolio_cpt = isset($opt['is_portfolio_cpt']) ? $opt['is_portfolio_cpt'] : '1';

			// Extra functions
			require_once __DIR__ . '/inc/extra.php';

            // Custom post types
            if ( $is_service_cpt == '1' ) {
                require_once __DIR__ . '/post-type/service.pt.php';
            }
            if ( $is_portfolio_cpt == '1' ) {
                require_once __DIR__ . '/post-type/portfolio.pt.php';
            }

            require_once __DIR__ . '/post-type/split_contents.pt.php';

            require_once __DIR__ . '/post-type/none.pt.php';

            /**
             * Register widget area.
             *
             * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
             */
			require_once __DIR__ . '/wp-widgets/widgets.php';

			// Elementor custom field icons
			require_once __DIR__ . '/fields/icons.php';

            // RGBA color picker
            require plugin_dir_path(__FILE__) . '/inc/acf-rgba-color-picker/acf-rgba-color-picker.php';


            /**
             * Saving automatically the ACF group fields json files
             */
            add_filter('acf/settings/save_json', function ( $path ) {

                // update path
                $path = plugin_dir_path(__FILE__) . 'inc/acf-json';

                // return
                return $path;

            });

            /**
             * Loading the saved ACF fields
             */
            add_filter('acf/settings/load_json', function ( $paths ) {
                // append path
                $paths[] = plugin_dir_path(__FILE__) . 'inc/acf-json';

                // return
                return $paths;
            });

            //one page scrolling file
            if( is_readable( __DIR__ . '/inc/page-scroll/page-scroll.php')){
                if ( !class_exists('\DROIT_ELEMENTOR_PRO\DL_Page_Scroll') ) {
                    require_once __DIR__ . '/inc/page-scroll/page-scroll.php';
                    \DROIT_ELEMENTOR_PRO\DL_Page_Scroll::instance()->init();
                }
            }

		}

		/**
		 * Init Hooks
		 *
		 * Hook into actions and filters.
		 *
		 * @since 1.7.0
		 *
		 * @access private
		 */
		private function init_hooks() {
			add_action( 'init', [ $this, 'i18n' ] );
			add_action( 'plugins_loaded', [ $this, 'init' ] );
		}

		/**
		 * Load Textdomain
		 *
		 * Load plugin localization files.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function i18n() {
			load_plugin_textdomain( 'wavee-core', false, plugin_basename( dirname( __FILE__ ) ) . '/languages' );
		}


		/**
		 * Init Wavee Core
		 *
		 * Load the plugin after Elementor (and other plugins) are loaded.
		 *
		 * @since 1.0.0
		 * @since 1.7.0 The logic moved from a standalone function to this class method.
		 *
		 * @access public
		 */
		public function init() {

			if ( !did_action( 'elementor/loaded' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
				return;
			}

			// Check for required Elementor version

			if ( !version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
				return;
			}

			// Check for required PHP version

			if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
				return;
			}

			// Add new Elementor Categories
			add_action( 'elementor/init', [ $this, 'add_elementor_category' ] );

			// Register Widget Scripts
			add_action( 'elementor/frontend/after_register_scripts', [ $this, 'register_widget_scripts' ] );
			add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'register_widget_scripts' ] );
            add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'enqueue_scripts' ], 5);
            //add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_scripts' ] );


			// Register Widget Scripts
            add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'enqueue_widget_styles' ] );
            add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'enqueue_widget_styles' ] );

			// Register New Widgets
            add_action( 'elementor/widgets/widgets_registered', [ $this, 'on_widgets_registered' ] );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have Elementor installed or activated.
		 *
		 * @since 1.1.0
		 * @since 1.7.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_missing_main_plugin() {
			$message = sprintf(
			/* translators: 1: Wavee Core 2: Elementor */
				esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'wavee-core' ),
				'<strong>' . esc_html__( 'Wavee core', 'wavee-core' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'wavee-core' ) . '</strong>'
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required Elementor version.
		 *
		 * @since 1.1.0
		 * @since 1.7.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_minimum_elementor_version() {
			$message = sprintf(
			/* translators: 1: Wavee Core 2: Elementor 3: Required Elementor version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'wavee-core' ),
				'<strong>' . esc_html__( 'Wavee Core', 'wavee-core' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'wavee-core' ) . '</strong>',
				self::MINIMUM_ELEMENTOR_VERSION
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required PHP version.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function admin_notice_minimum_php_version() {
			$message = sprintf(
			/* translators: 1: Wavee Core 2: PHP 3: Required PHP version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'wavee-core' ),
				'<strong>' . esc_html__( 'Wavee Core', 'wavee-core' ) . '</strong>',
				'<strong>' . esc_html__( 'PHP', 'wavee-core' ) . '</strong>',
				self::MINIMUM_PHP_VERSION
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		/**
		 * Add new Elementor Categories
		 *
		 * Register new widget categories for Wavee Core widgets.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		public function add_elementor_category() {
			\Elementor\Plugin::instance()->elements_manager->add_category( 'wavee-elements', [
				'title' => __( 'Wavee Elements', 'wavee-core' ),
			], 1 );
		}

		/**
		 * Register Widget Scripts
		 *
		 * Register custom scripts required to run Wavee Core.
		 *
		 * @since 1.6.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */

		public function register_widget_scripts() {

            wp_register_script( 'scroll-overflow', plugins_url( 'assets/vendors/fullpage/scroll-overflow.js', __FILE__ ), ['jquery'], '0.0.1', true );
            wp_register_script( 'fullpage', plugins_url( 'assets/vendors/fullpage/fullpage.js', __FILE__ ), ['jquery'], '3.0.7', true );
            wp_register_script( 'ajax-chimp', plugins_url( 'assets/js/ajax-chimp.js', __FILE__ ), ['jquery'], '1.0', true );
            wp_register_script( 'imagesloaded', plugins_url( 'assets/vendors/imagesloaded/imagesloaded.pkgd.min.js', __FILE__ ), ['jquery'], '4.1.0', true );
            wp_register_script( 'isotope', plugins_url( 'assets/vendors/isotope/isotope-min.js', __FILE__ ), ['jquery'], '3.0.1', true );
            wp_register_script( 'YTPlayer', plugins_url( 'assets/vendors/plyr/jquery.mb.YTPlayer.js', __FILE__ ), ['jquery'], '1.0.0', true );

            // Home Split
            wp_register_script( 'jquery-easings', plugins_url( 'assets/vendors/multiscroll/jquery.easings.min.js', __FILE__ ), ['jquery'], '1.9.2', true );
            wp_register_script( 'multiscroll', plugins_url( 'assets/vendors/multiscroll/multiscroll.responsiveExpand.min.js', __FILE__ ), ['jquery'], '0.1.5', true );
            wp_register_script( 'multiscroll-extensions', plugins_url( 'assets/vendors/multiscroll/jquery.multiscroll.extensions.min.js', __FILE__ ), ['jquery'], '0.1.5', true );
            wp_register_script( 'multi', plugins_url( 'assets/vendors/multiscroll/multi.js', __FILE__ ), ['jquery'], '1.0', true );
            wp_register_script( 'wavee-home-split', plugins_url( 'assets/vendors/multiscroll/home-split.js', __FILE__ ), ['jquery'], '1.0', true );

            // Split Homepage
            if ( is_page_template('page-split.php') ) {
                wp_enqueue_script('jquery-easings');
                wp_enqueue_script('multiscroll');
                wp_enqueue_script('multiscroll-extensions');
                wp_enqueue_script('multi');
                //wp_enqueue_script('scroll-overflow');
                //wp_enqueue_script('fullpage');
                wp_enqueue_script('wavee-home-split');
            }

            // New Home Pages
            wp_register_script( 'splitting', plugins_url( 'assets/vendors/spiling/splitting.min.js', __FILE__ ), ['jquery'], '1.0', true );
            wp_register_script( 'wavee-swiper', plugins_url( 'assets/vendors/swiper/swiper.min.js', __FILE__ ), ['jquery'], '4.4.6', true );

            // Wavee Demo
            wp_register_script( 'owl-carousel', plugins_url( 'assets/demo/js/owl.carousel.min.js', __FILE__ ), ['jquery'], '2.3.4', true );
            wp_register_script( 'parallax-min', plugins_url( 'assets/demo/js/parallax.min.js', __FILE__ ), ['jquery'], '1.0', true );
            wp_register_script( 'parallax-scroll', plugins_url( 'assets/demo/js/parallax-scroll.js', __FILE__ ), ['jquery'], '1.0', true );
            wp_register_script( 'scrollspy', plugins_url( 'assets/demo/js/scrollspy.js', __FILE__ ), ['jquery'], '1.0', true );
            wp_enqueue_script( 'easing', plugins_url( 'assets/demo/js/easing.min.js', __FILE__ ), ['jquery'], '1.0', true );
            wp_enqueue_script( 'mCustomScrollbar', plugins_url( 'assets/demo/js/mCustomScrollbar.js', __FILE__ ), ['jquery'], '2.3.2 ', true );
            wp_register_script( 'waypoints', plugins_url( 'assets/demo/js/waypoints.min.js', __FILE__ ), ['jquery'], '2.0.3', true );
            wp_register_script( 'counterup', plugins_url( 'assets/demo/js/counterup.min.js', __FILE__ ), ['jquery'], '1.0', true );

            if ( !is_page_template( 'page-split.php' ) ) {
                wp_enqueue_script('wave-core-custom', plugins_url('assets/js/custom.js', __FILE__), ['jquery'], '1.0.0', true);
            }


		}

		/**
		 * Register Widget Styles
		 *
		 * Register custom styles required to run Wavee Core.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		
		public function enqueue_widget_styles() {
		    // New Home Pages
            wp_register_style( 'fullpage', plugins_url( 'assets/vendors/fullpage/fullpage.css', __FILE__) );
            wp_register_style( 'YTPlayer', plugins_url( 'assets/vendors/plyr/jquery.mb.YTPlayer.min.css', __FILE__) );
            wp_register_style( 'splitting', plugins_url( 'assets/vendors/spiling/splitting.css', __FILE__) );
            wp_register_style( 'swiper', plugins_url( 'assets/vendors/swiper/swiper.min.css', __FILE__) );

            wp_register_style( 'jquery-multiscroll', plugins_url( 'assets/vendors/multiscroll/jquery.multiscroll.css', __FILE__) );

            //Wavee Demo
            wp_register_style( 'owl-theme', plugins_url( 'assets/demo/css/owl.theme.default.min.css', __FILE__) );
            wp_register_style( 'owl-carousel', plugins_url( 'assets/demo/css/owl.carousel.min.css', __FILE__) );

            if ( is_rtl() ) {
                wp_register_style( 'wavee-demo', plugins_url( 'assets/demo/css/wavee-demo-rtl.css', __FILE__) );
            } else {
                wp_register_style( 'wavee-demo', plugins_url( 'assets/demo/css/wavee-demo.css', __FILE__) );
            }

            if ( defined( 'ELEMENTOR_VERSION') ) {
                if ( \Elementor\Plugin::$instance->preview->is_preview_mode() ) {
                    wp_enqueue_style( 'owl-carousel' );
                    wp_enqueue_style( 'owl-theme' );
                    wp_enqueue_style( 'wavee-demo' );
                }
            }

            // Split Homepage
            if ( is_page_template('page-split.php') ) {
                wp_enqueue_style('jquery-multiscroll');
            }



		}

        public function enqueue_scripts() {

            wp_enqueue_script( 'wavee-elementor', plugins_url( 'assets/js/wavee-elementor.js', __FILE__ ), [ 'jquery', 'elementor-frontend'], '1.0', true );

        }

        /**
		 * Register New Widgets
		 *
		 * Include Wavee Core widgets files and register them in Elementor.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		public function on_widgets_registered() {
			$this->include_widgets();
			$this->register_widgets();
		}

		/**
		 * Include Widgets Files
		 *
		 * Load Wavee Core widgets files.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access private
		 */
		private function include_widgets() {
			require_once __DIR__ . '/widgets/heros/Wavee_hero.php';
			require_once __DIR__ . '/widgets/call-to-action/Wavee_c2a.php';
			require_once __DIR__ . '/widgets/Wavee_subscribe_form.php';
			require_once __DIR__ . '/widgets/Wavee_single_video.php';
			require_once __DIR__ . '/widgets/features/Wavee_features.php';
			require_once __DIR__ . '/widgets/Wavee_team.php';
			require_once __DIR__ . '/widgets/Wavee_testimonials.php';
			require_once __DIR__ . '/widgets/Wavee_clients_logo.php';
			require_once __DIR__ . '/widgets/Wavee_socials.php';
			require_once __DIR__ . '/widgets/portfolio/Wavee_portfolio.php';
			require_once __DIR__ . '/widgets/services/Wavee_service.php';
			require_once __DIR__ . '/widgets/Wavee_contact_form.php';
			require_once __DIR__ . '/widgets/full-screen-slider/Wavee_full_screen_slider.php';
			require_once __DIR__ . '/widgets/Wavee_service_tabs.php';
			require_once __DIR__ . '/widgets/Wavee_Portfolio_masonry.php';
			require_once __DIR__ . '/widgets/Wavee_split_contents.php';
			require_once __DIR__ . '/widgets/Wavee_animated_images.php';

			//Wavee Demo
			require_once __DIR__ . '/widgets/two-column-features/Wavee_two_column_features.php';
			require_once __DIR__ . '/widgets/image-carousel/Wavee_image_carousel.php';

        }

		/**
		 * Register Widgets
		 *
		 * Register Wavee Core widgets.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access private
		 */
		private function register_widgets() {
			// Site Elements
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_hero() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_c2a() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_subscribe_form() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_single_video() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_features() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_team() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_testimonials() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_clients_logo() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_socials() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_portfolio() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_service() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_contact_form() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_full_screen_slider() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_service_tabs() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_Portfolio_masonry() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_split_contents() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_animated_images() );

			//Wavee Demo
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_two_column_features() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \WaveeCore\Widgets\Wavee_image_carousel() );

		}
	}
}
// Make sure the same function is not loaded twice in free/premium versions.

if ( !function_exists( 'wavee_core_load' ) ) {
	/**
	 * Load Wavee Core
	 *
	 * Main instance of Wavee_Core.
	 *
	 * @since 1.0.0
	 * @since 1.7.0 The logic moved from this function to a class method.
	 */
	function wavee_core_load() {
		return Wavee_core::instance();
	}

	// Run Wavee Core
    wavee_core_load();
}


function wavee_admin_cpt_script( ) {

}
add_action( 'admin_enqueue_scripts', 'wavee_admin_cpt_script', 10, 1 );