<?php
/**
 * Custom Post Types
 */
Redux::set_section( 'wavee_opt', array(
    'title'     => esc_html__( 'Custom Post Types', 'wavee' ),
    'id'        => 'cpt_opt',
    'icon'      => 'dashicons dashicons-admin-post',
));

/**
 * Post Types
 */
Redux::set_section( 'wavee_opt', array(
    'title'     => esc_html__( 'Post Types', 'wavee' ),
    'id'        => 'cpt',
    'icon'      => '',
    'subsection'=> true,
    'fields'    => array(
        array(
            'id'        => 'cpt_note',
            'type'      => 'info',
            'style'     => 'success',
            'title'     => esc_html__( 'Enable Disable Custom Post Types', 'wavee' ),
            'icon'      => 'dashicons dashicons-info',
            'desc'      => esc_html__( 'If you want, you can disable any custom post type of Wavee from here.', 'wavee' )
        ),

        array(
            'id'       => 'is_service_cpt',
            'type'     => 'switch',
            'title'    => esc_html__('Services', 'wavee' ),
            'on'       => esc_html__( 'Enabled', 'wavee' ),
            'off'      => esc_html__( 'Disabled', 'wavee' ),
            'default'  => true,
        ),

        array(
            'id'       => 'is_portfolio_cpt',
            'type'     => 'switch',
            'title'    => esc_html__('Portfolios', 'wavee' ),
            'on'       => esc_html__( 'Enabled', 'wavee' ),
            'off'      => esc_html__( 'Disabled', 'wavee' ),
            'default'  => true,
        ),
    )
));

/**
 * Slug Re-write
 */
Redux::set_section( 'wavee_opt', array(
    'title'     => esc_html__( 'Post Type Slugs', 'wavee' ),
    'id'        => 'wavee_cp_slugs',
    'icon'      => '',
    'subsection'=> true,
    'fields'    => array(
        array(
            'id'        => 'cp_slug_note',
            'type'      => 'info',
            'style'     => 'warning',
            'title'     => esc_html__( 'Slug Re-write:', 'wavee' ),
            'icon'      => 'dashicons dashicons-info',
            'desc'      => sprintf (
                '%1$s <a href="%2$s"> %3$s</a> %4$s',
                esc_html__( "These are the custom post's slugs offered by Wavee. You can customize the permalink structure (site_domain/post_type_slug/post_slug) by changing the post type slug (post_type_slug) from here. Don't forget to save the permalinks settings from", 'wavee' ),
                get_admin_url( null, 'options-permalink.php' ),
                esc_html__( 'Settings > Permalinks', 'wavee' ),
                esc_html__( 'after changing the slug value.', 'wavee' )
            )
        ),
        
        array(
            'title'     => esc_html__( 'Service Slug', 'wavee' ),
            'id'        => 'service_slug',
            'type'      => 'text',
            'required'  => array( 'is_service_cpt', '=', '1' ),
            'default'   => 'service'
        ),
        
        array(
            'title'     => esc_html__( 'Portfolio Slug', 'wavee' ),
            'id'        => 'portfolio_slug',
            'type'      => 'text',
            'required'  => array( 'is_portfolio_cpt', '=', '1' ),
            'default'   => 'portfolio'
        ),
    )
));



/**
 * Portfolio
 */
Redux::set_section( 'wavee_opt', array(
    'title'         => esc_html__( 'Portfolio', 'wavee' ),
    'id'            => 'portfolio_settings',
    'icon'          => '',
    'subsection'    => true,
    'fields'        => array(
        array(
            'id'        => 'portfolio_note',
            'type'      => 'info',
            'style'     => 'success',
            'title'     => esc_html__( 'Important Note', 'wavee' ),
            'icon'      => 'dashicons dashicons-info',
            'required'  => array( 'is_portfolio_cpt', '=', '' ),
            'desc'      => esc_html__( "Portfolio post type is disabled that's why the portfolio settings are gone from here. Enable the portfolio post type from 'Theme Settings > Custom Post Types > Post Types' To show the portfolio settings.", 'wavee' )
        ),

        array(
            'title'     => esc_html__('Banner Style', 'wavee'),
            'subtitle'  => esc_html__('Select the default portfolio layout for portfolio details page', 'wavee'),
            'id'        => 'portfolio_banner_style',
            'type'      => 'select',
            'options'   => array(
                'style_01' => esc_html__('Style One', 'wavee'),
                'style_02' => esc_html__('Style Two', 'wavee'),
            ),
            'required'  => array( 'is_portfolio_cpt', '=', '1' ),
            'default'   => 'style_01'
        ),

        array(
            'title'     => esc_html__('Default Layout', 'wavee'),
            'subtitle'  => esc_html__('Select the default portfolio layout for portfolio details page', 'wavee'),
            'id'        => 'portfolio_layout',
            'type'      => 'select',
            'options'   => array(
                'top_img_bottom_contents' => esc_html__('Top Image Bottom Contents', 'wavee'),
                'left_img_right_contents' => esc_html__('Left Image Right Contents', 'wavee'),
                'top_img_bottom_contents2' => esc_html__('Top Images Bottom Contents 02', 'wavee'),
            ),
            'required'  => array( 'is_portfolio_cpt', '=', '1' ),
            'default'   => 'top_img_bottom_contents'
        ),

        // Portfolio Share Options
        array(
            'id' => 'portfolio_share_start',
            'type' => 'section',
            'title' => __('Share Options', 'wavee'),
            'subtitle' => __('Enable/Disable social media share options as you want.', 'wavee'),
            'required'  => array( 'is_portfolio_cpt', '=', '1' ),
            'indent' => true
        ),

        array(
            'id'       => 'portfolio_share_options',
            'type'     => 'switch',
            'title'    => esc_html__('Share Options', 'wavee'),
            'default'  => true,
            'on'       => esc_html__('Show', 'wavee'),
            'off'      => esc_html__('Hide', 'wavee'),
            'required'  => array( 'is_portfolio_cpt', '=', '1' ),
        ),
        array(
            'id'       => 'portfolio_share_title',
            'type'     => 'text',
            'title'    => esc_html__('Title', 'wavee'),
            'default'  => esc_html__('Share', 'wavee'),
            'required' => array('portfolio_share_options','=','1'),
        ),
        array(
            'id'       => 'is_portfolio_fb',
            'type'     => 'switch',
            'title'    => esc_html__('Facebook', 'wavee'),
            'default'  => true,
            'required' => array('portfolio_share_options','=','1'),
            'on'       => esc_html__('Show', 'wavee'),
            'off'      => esc_html__('Hide', 'wavee'),
        ),
        array(
            'id'       => 'is_portfolio_twitter',
            'type'     => 'switch',
            'title'    => esc_html__('Twitter', 'wavee'),
            'default'  => true,
            'required' => array('portfolio_share_options','=','1'),
            'on'       => esc_html__('Show', 'wavee'),
            'off'      => esc_html__('Hide', 'wavee'),
        ),

        array(
            'id'       => 'is_portfolio_pinterest',
            'type'     => 'switch',
            'title'    => esc_html__('Pinterest', 'wavee'),
            'default'  => true,
            'required' => array('portfolio_share_options','=','1'),
            'on'       => esc_html__('Show', 'wavee'),
            'off'      => esc_html__('Hide', 'wavee'),
        ),

        array(
            'id'       => 'is_portfolio_linkedin',
            'type'     => 'switch',
            'title'    => esc_html__('Linkedin', 'wavee'),
            'default'  => true,
            'required' => array('portfolio_share_options','=','1'),
            'on'       => esc_html__('Show', 'wavee'),
            'off'      => esc_html__('Hide', 'wavee'),
        ),

        array(
            'id'     => 'portfolio_share_end',
            'type'   => 'section',
            'indent' => false,
        ),
    )
));
